Version 3.0.1
authorGary Scavone <gary@music.mcgill.ca>
Wed, 9 Oct 2013 21:47:55 +0000 (23:47 +0200)
committerStephen Sinclair <sinclair@music.mcgill.ca>
Wed, 9 Oct 2013 23:08:39 +0000 (01:08 +0200)
RtAudio.cpp
RtAudio.h
doc/doxygen/tutorial.txt
doc/release.txt

index 4211e4e3654f7a42248a68547996ef714267731b..767908d2a75e780ab92aa8bd3f5be036c94487e1 100644 (file)
@@ -37,7 +37,7 @@
 */
 /************************************************************************/
 
-// RtAudio: Version 3.0, 11 March 2004
+// RtAudio: Version 3.0.1, 22 March 2004
 
 #include "RtAudio.h"
 #include <iostream>
@@ -5489,7 +5489,7 @@ void RtApiDs :: probeDeviceInfo(RtApiDevice *info)
   }
   else {
     // Check input rates against output rate range.
-    for ( unsigned int i=info->sampleRates.size()-1; i>=0; i-- ) {
+    for ( int i=info->sampleRates.size()-1; i>=0; i-- ) {
       if ( (unsigned int) info->sampleRates[i] > out_caps.dwMaxSecondarySampleRate )
         info->sampleRates.erase( info->sampleRates.begin() + i );
     }
index cf39ab426f09a442993b95ffb1454dd5fbae0c2c..fa2d494d297949d2b37b08e357895293d75cde2e 100644 (file)
--- a/RtAudio.h
+++ b/RtAudio.h
@@ -37,7 +37,7 @@
 */
 /************************************************************************/
 
// RtAudio: Version 3.0, 11 March 2004
 
 #ifndef __RTAUDIO_H
 #define __RTAUDIO_H
@@ -186,8 +186,7 @@ protected:
 
     RtApiStream()
       :apiHandle(0), userBuffer(0), deviceBuffer(0) {}
-    //      :apiHandle(0), mode(UNINITIALIZED), state(STREAM_STOPPED),
-    //       userBuffer(0), deviceBuffer(0) {}
+    //      mode(UNINITIALIZED), state(STREAM_STOPPED),
   };
 
   // A protected device structure for audio devices.
index 6623c0e5f2ee8dedc022ab0dbea5b506343df602..9b45bbc5d9d07ef9cd97b011b72b6ed7ece54b7b 100644 (file)
@@ -38,7 +38,7 @@ The RtError class declaration and definition have been extracted to a separate f
 
 \section download Download
 
-Latest Release (11 March 2004): <A href="http://music.mcgill.ca/~gary/rtaudio/release/rtaudio-3.0.tar.gz">Version 3.0 (200 kB tar/gzipped)</A>
+Latest Release (22 March 2004): <A href="http://music.mcgill.ca/~gary/rtaudio/release/rtaudio-3.0.1.tar.gz">Version 3.0.1 (200 kB tar/gzipped)</A>
 
 \section start Getting Started
 
index b1719161577c6085d3cbc34960efce73fc2bf2d2..ad9c8e982196421cb9597240b7f9fa4f10d2f8bc 100644 (file)
@@ -2,6 +2,9 @@ RtAudio - a set of C++ classes which provide a common API for realtime audio inp
 
 By Gary P. Scavone, 2001-2004.
 
+v3.0.1: (22 March 2004)
+- bug fix in Windows DirectSound support for cards with output only
+
 v3.0: (11 March 2004)
 - added Linux Jack audio server support
 - new multi-api support by subclassing all apis and making rtaudio a controller class
@@ -37,7 +37,7 @@
 /************************************************************************/
 
-// RtAudio: Version 3.0, 11 March 2004
+// RtAudio: Version 3.0.1, 22 March 2004
 
 #ifndef __RTAUDIO_H